| rmdcev | R Documentation |
The 'rmdcev' R package estimates and simulates Kuhn-Tucker demand models with individual heterogeneity. The models supported by 'rmdcev' are the multiple-discrete continuous extreme value (MDCEV) model and Kuhn-Tucker specification common in the environmental economics literature on recreation demand. Latent class and random parameters specifications can be implemented and the models are fit using maximum likelihood estimation or Bayesian estimation. All models are implemented in 'Stan' (see Stan Development Team, 2019) <https://mc-stan.org/>. The 'rmdcev' package also implements demand forecasting (Pinjari and Bhat (2011) <https://repositories.lib.utexas.edu/handle/2152/23880>) and welfare calculation (Lloyd-Smith (2018) <doi:10.1016/j.jocm.2017.12.002>) for policy simulation.
Maintainer: Patrick Lloyd-Smith patrick.lloydsmith@usask.ca
Other contributors:
Trustees of Columbia University [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.